@@ -26,11 +26,10 @@ from collections.abc import Iterable
 from contextlib import closing, suppress
 from dataclasses import dataclass
 from datetime import timedelta
-from typing import TYPE_CHECKING, Callable, Generator, Protocol, cast
+from typing import TYPE_CHECKING, Generator, Protocol, cast
 
 import pendulum
 import tenacity
-from deprecated import deprecated
 from kubernetes import client, watch
 from kubernetes.client.rest import ApiException
 from kubernetes.stream import stream as kubernetes_stream
@@ -39,7 +38,7 @@ from pendulum.parsing.exceptions import ParserError
 from typing_extensions import Literal
 from urllib3.exceptions import HTTPError, TimeoutError
 
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException
 from airflow.providers.cncf.kubernetes.callbacks import ExecutionMode, KubernetesPodOperatorCallback
 from airflow.providers.cncf.kubernetes.utils.xcom_sidecar import PodDefaults
 from airflow.utils.log.logging_mixin import LoggingMixin
@@ -302,19 +301,15 @@ class PodManager(LoggingMixin):
         self,
         kube_client: client.CoreV1Api,
         callbacks: type[KubernetesPodOperatorCallback] | None = None,
-        progress_callback: Callable[[str], None] | None = None,
     ):
         """
         Create the launcher.
 
         :param kube_client: kubernetes client
         :param callbacks:
-        :param progress_callback: Callback function invoked when fetching container log.
-            This parameter is deprecated, please use ````
         """
         super().__init__()
         self._client = kube_client
-        self._progress_callback = progress_callback
         self._watch = watch.Watch()
         self._callbacks = callbacks
 
@@ -383,16 +378,6 @@ class PodManager(LoggingMixin):
                 raise PodLaunchFailedException(msg)
             time.sleep(startup_check_interval)
 
-    @deprecated(
-        reason=(
-            "Method `follow_container_logs` is deprecated.  Use `fetch_container_logs` instead "
-            "with option `follow=True`."
-        ),
-        category=AirflowProviderDeprecationWarning,
-    )
-    def follow_container_logs(self, pod: V1Pod, container_name: str) -> PodLoggingStatus:
-        return self.fetch_container_logs(pod=pod, container_name=container_name, follow=True)
-
     def fetch_container_logs(
         self,
         pod: V1Pod,
@@ -461,8 +446,6 @@ class PodManager(LoggingMixin):
                                 progress_callback_lines.append(line)
                             else:  # previous log line is complete
                                 for line in progress_callback_lines:
-                                    if self._progress_callback:
-                                        self._progress_callback(line)
                                     if self._callbacks:
                                         self._callbacks.progress_callback(
                                             line=line, client=self._client, mode=ExecutionMode.SYNC
@@ -479,8 +462,6 @@ class PodManager(LoggingMixin):
                 finally:
                     # log the last line and update the last_captured_timestamp
                     for line in progress_callback_lines:
-                        if self._progress_callback:
-                            self._progress_callback(line)
                         if self._callbacks:
                             self._callbacks.progress_callback(
                                 line=line, client=self._client, mode=ExecutionMode.SYNC
